#!/usr/bin/env python3
"""
Legacy setup.py for Sanitizr.
The primary build configuration is in pyproject.toml.
This file is provided for backward compatibility.
"""

from setuptools import setup

if __name__ == "__main__":
    setup()
